# -*- coding: utf-8 -*-
#
# Created on Oct 15, 2013
# @authors: Jiri Spilka
# http://people.ciirc.cvut.cz/~spilkjir
# @2015, CIIRC, Czech Technical University in Prague
#
# Licensed under the terms of the GNU GENERAL PUBLIC LICENSE
# (see CTGViewerLite.py for details)

import os
import sys
import numpy as np

"""
"static" functions
"""

# log = logging.getLogger(Config.logger_name)


def ensure_dir(sdir):
    if not os.path.exists(sdir):
        os.makedirs(sdir)


def file_exists(infile):
    """ check if a file exist """
    if os.path.exists(infile):
        return True
    else:
        # log.error("File not exists: {0}".format(inFile))
        return False


def get_filename_with_ext(infile):
    dummy, file_name_with_ext = os.path.split(infile)
    return file_name_with_ext


def get_filename_without_ext(infile):
    file1 = get_filename_with_ext(infile)
    file_name, dummy = os.path.splitext(file1)
    return file_name


def get_filename_and_ext(infile):
    file1 = get_filename_with_ext(infile)
    file_name, ext = os.path.splitext(file1)
    return file_name, ext


def get_number_lines_in_stream(fstream):
    """ count lines in a stream, when done return stream to the beginning of a file """
    lines = 0
    buf_size = 1024 * 1024
    read_f = fstream.read  # loop optimization

    buf = read_f(buf_size)
    while buf:
        lines += buf.count('\n')
        buf = read_f(buf_size)

    fstream.seek(0)
    return lines


def get_mumber_lines(filename):
    """ count lines in a file """

    f = open(filename, "r+")
    lines = get_number_lines_in_stream(f)
    f.close()
    return lines


def get_files_with_ext_mask(dir_name, ext_mask):
    """
    Get all files in directory with specified extension
    :param dir_name:
    :param ext_mask:
    :return: list of files
    :rtype: list()
    """
    if ext_mask[0] == '.':
        ext_mask = ext_mask[1:]

    files = directory_listing(dir_name)
    output = list()
    for f in files:
        dummy, ext = get_filename_and_ext(f)

        if len(ext) == 0:
            continue

        if ext[0] == '.':
            ext = ext[1:]

        if ext_mask == ext:
            output.append(f)

    return output


def directory_listing(dir_name):
    output = []
    for dirname, dummy, filenames in os.walk(dir_name):
        for filename in filenames:
            output.append(os.path.join(dirname, filename))

    return output


def get_application_path():
    """ determine if application is a script file or frozen exe """
    if getattr(sys, 'frozen', False):
        return os.path.dirname(sys.executable)
    elif __file__:
        return os.path.dirname(__file__)


def remove_nans_at_begin_and_end(x):

    # if a signal begins or ends with NaNs --> do not interpolate there
    gap_at_begin = []
    ind_samples1 = np.where(x != 0)[0]

    if len(ind_samples1) > 0:
        if ind_samples1[0] != 0: # if there is no signal at position 0
            gap_at_begin = np.arange(0, ind_samples1[0])

    gap_at_end = []
    ind_samples2 = np.where(x != 0)[0]
    if len(ind_samples2) > 0:
        if ind_samples2[-1] != len(x):
            gap_at_end = np.arange(ind_samples2[-1]+1, len(x))

    ifrom = ind_samples1[0]
    ito = ind_samples2[-1]+1
    x_out = x[ifrom:ito]
    return x_out, gap_at_begin, gap_at_end, ifrom, ito


